==> _private_core_network-1.2.54.tar.gz: lib/network_resources/model/pro_event_param.dart <==
class ProEventParam {
  int? proId;
  int? datetimeStart;
  int? datetimeStop;
  String? type;
  String? eventTitle;
  String? moreInfos;
  double? lat;
  double? lng;
  int? placeId;
  String? imageUrl;
  int? cancelTimeUpTo;
  int? callDuration;

  ProEventParam(
      {this.proId,
      this.datetimeStart,
      this.datetimeStop,
      this.type,
      this.eventTitle,
      this.moreInfos,
      this.lat,
      this.lng,
      this.placeId,
      this.imageUrl,
      this.cancelTimeUpTo,
      this.callDuration});

  ProEventParam.fromJson(Map<String, dynamic> json) {
    proId = json['proId'];
    datetimeStart = json['datetimeStart'];
    datetimeStop = json['datetimeStop'];
    type = json['type'];
    eventTitle = json['eventTitle'];
    moreInfos = json['moreInfos'];
    lat = json['lat'];
    lng = json['lng'];
    placeId = json['placeId'];
    imageUrl = json['imageUrl'];
    cancelTimeUpTo = json['cancelTimeUpTo'];
    callDuration = json['callDuration'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['proId'] = this.proId;
    data['datetimeStart'] = this.datetimeStart;
    data['datetimeStop'] = this.datetimeStop;
    data['type'] = this.type;
    data['eventTitle'] = this.eventTitle;
    data['moreInfos'] = this.moreInfos;
    data['lat'] = this.lat;
    data['lng'] = this.lng;
    data['placeId'] = this.placeId;
    data['imageUrl'] = this.imageUrl;
    data['cancelTimeUpTo'] = this.cancelTimeUpTo;
    data['callDuration'] = this.callDuration;
    return data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/pro_event_param.dart <==
class ProEventParam {
  int? proId;
  int? datetimeStart;
  int? datetimeStop;
  String? type;
  String? eventTitle;
  String? moreInfos;
  double? lat;
  double? lng;
  int? placeId;
  String? imageUrl;
  int? cancelTimeUpTo;
  int? callDuration;

  ProEventParam(
      {this.proId,
      this.datetimeStart,
      this.datetimeStop,
      this.type,
      this.eventTitle,
      this.moreInfos,
      this.lat,
      this.lng,
      this.placeId,
      this.imageUrl,
      this.cancelTimeUpTo,
      this.callDuration});

  ProEventParam.fromJson(Map<String, dynamic> json) {
    proId = json['proId'];
    datetimeStart = json['datetimeStart'];
    datetimeStop = json['datetimeStop'];
    type = json['type'];
    eventTitle = json['eventTitle'];
    moreInfos = json['moreInfos'];
    lat = json['lat'];
    lng = json['lng'];
    placeId = json['placeId'];
    imageUrl = json['imageUrl'];
    cancelTimeUpTo = json['cancelTimeUpTo'];
    callDuration = json['callDuration'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['proId'] = proId;
    data['datetimeStart'] = datetimeStart;
    data['datetimeStop'] = datetimeStop;
    data['type'] = type;
    data['eventTitle'] = eventTitle;
    data['moreInfos'] = moreInfos;
    data['lat'] = lat;
    data['lng'] = lng;
    data['placeId'] = placeId;
    data['imageUrl'] = imageUrl;
    data['cancelTimeUpTo'] = cancelTimeUpTo;
    data['callDuration'] = callDuration;
    return data;
  }
}
